#
# Copyright (c) 2015-2024 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""


MSC_PRICE_API_ROUTE = 'pyams_msc.theater.price'
'''MSC price API route'''

MSC_PRICE_API_PATH = '/api/msc/{theater_name}/price'
'''MSC price API default path'''


MSC_ROOM_API_ROUTE = 'pyams_msc.theater.room'
'''MSC room API route'''

MSC_ROOM_API_PATH = '/api/msc/{theater_name}/room/{room_id}'
'''MSC room API default path'''
